@@ -59,11 +59,11 @@ def apply_performance_mode(training_target, test_target, training_prediction, te
     training_target.loc[:,('prediction')] = training_prediction
     test_target.loc[:,('prediction')] = test_prediction
     
-    data = training_target.append(test_target)
-    training_temporal_ids = training_target['temporal id'].unique()
+    data = pd.concat([training_target, test_target], ignore_index=True)
+    # training_temporal_ids = training_target['temporal id'].unique()
     test_temporal_ids = test_target['temporal id'].unique()
     
-    if same_train_test == True:
+    if same_train_test:
         data = training_target.copy()
         test_temporal_ids = []
         test_prediction = []
@@ -106,7 +106,7 @@ def apply_performance_mode(training_target, test_target, training_prediction, te
         if window > len(temporal_ids):
             raise ValueError("The specified window for the moving average performance_mode is too large for the input data.")
         
-        number_of_spatial_units = len(data['spatial id'].unique())
+        # number_of_spatial_units = len(data['spatial id'].unique())
         
         # practical accessible values (target real values in training set and predicted values in test set) will be used 
         # to get the moving average target (predicted)
@@ -150,7 +150,7 @@ def apply_performance_mode(training_target, test_target, training_prediction, te
     training_set = data[data['type'] == 1]
     test_set = data[data['type'] == 2]
     
-    if same_train_test == True:
+    if same_train_test:
         test_set = training_set.copy()
     
     if (len(test_set) < 1) and (performance_mode == 'moving_average'):
