@@ -20,13 +20,13 @@ def select_features(data, ordered_covariates_or_features):
     # check if all elements in check_list meet the condition for being covariate type
     type_flag = all(re.search(' t$', element) or re.search(' t[+]$', element) for element in check_list)
     
-    if type_flag == False:    # ordered_features
+    if not type_flag:    # ordered_features
         output_data = data[ordered_covariates_or_features]
 
     elif type_flag == 1:    # ordered_covariates
         for covariate_name in ordered_covariates_or_features:
             # making a dataframe (tmp_df) containing the desirable columns
-            if not(covariate_name in check_list):
+            if covariate_name not in check_list:
                 tmp_df = data[[covariate_name]]
             else:
                 if covariate_name[-1] == '+':
